package org.rcisoft.bus.bcustomer.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.bus.bcustomer.dao.BCustomerRepository;
import org.rcisoft.bus.bcustomer.entity.BCustomer;
import org.rcisoft.bus.bcustomer.service.BCustomerService;
import org.rcisoft.core.exception.CyServiceException;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class BCustomerServiceImpl extends ServiceImpl<BCustomerRepository, BCustomer> implements BCustomerService{

    //保存
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(BCustomer bCustomer) {
        //  验重
        if (baseMapper.queryNumberSomeCode(bCustomer) > 0) {
            throw new CyServiceException(501,"该custcode已存在,请重新输入");
        }
        //增加操作
        int line = baseMapper.insert(bCustomer);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
                bCustomer.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(BCustomer bCustomer) {
        //删除
        int line = baseMapper.realDelete(bCustomer);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
                bCustomer.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(BCustomer bCustomer) {
        //逻辑删除
        int line = baseMapper.deleteById(bCustomer);
        log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                bCustomer.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(BCustomer bCustomer) {
        // 验重
        if (baseMapper.queryNumberSomeCode(bCustomer) > 0) {
            throw new CyServiceException(501,"该custcode已存在,请重新输入");
        }
        //修改操作
        int line = baseMapper.updateById(bCustomer);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+
                bCustomer.getBusinessId()+"的信息");
        return new CyPersistModel(line);
    }
    //根据id查询操作
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public BCustomer findById(String id) {
        return baseMapper.selectById(id);
    }
    //分页查询
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public IPage<BCustomer> findAllByPagination(CyPageInfo<BCustomer> paginationUtility, BCustomer bCustomer) {
        return baseMapper.queryBCustomersPaged(paginationUtility, bCustomer);
    }
    //查询
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public List<BCustomer> findAll(BCustomer bCustomer) {
        return baseMapper.queryBCustomers(bCustomer);
    }
    //导出
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public List<BCustomer> export(BCustomer bCustomer) {
        List<BCustomer> bCustomerList = baseMapper.queryBCustomers(bCustomer);
        return bCustomerList;
    }
}
